==> statistical-manager-service-1.4.4-20151016.124232-1-sources.jar: org/gcube/data/analysis/statisticalmanager/dataspace/exporter/CSVExporter.java <==
package org.gcube.data.analysis.statisticalmanager.dataspace.exporter;

import static org.gcube.data.analysis.statisticalmanager.persistence.DataBaseManager.closeConn;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;


import org.gcube.common.core.utils.logging.GCUBELog;
import org.gcube.data.analysis.statisticalmanager.exception.StatisticalManagerException;
import org.gcube.data.analysis.statisticalmanager.persistence.DataBaseManager;
import org.postgresql.copy.CopyManager;
import org.postgresql.core.BaseConnection;

public class CSVExporter {

	protected final GCUBELog logger = new GCUBELog(this);	
	private File file;
	private String tableId;
	
	public CSVExporter(String tableId, File file) {
		this.file = file;
		this.tableId = tableId;
	}
	
	public long exporterToFile() throws StatisticalManagerException, FileNotFoundException,
	SQLException, IOException
	 {
		
		Connection conn = null;
		CopyManager copyManager = null;
		try {
			conn = DriverManager.getConnection(DataBaseManager.getUrlDB(),
					DataBaseManager.getUsername(), DataBaseManager.getPassword());
			copyManager = new CopyManager((BaseConnection) conn);
		} catch (SQLException e) {
			closeConn(conn);
			throw new StatisticalManagerException();
		} 
		try {
			logger.debug("Try to retrieve resource");
//			long result = copyManager.copyOut(String.format("COPY %s TO STDOUT CSV HEADER QUOTE '\"' ESCAPE '\\'",
//					tableId), new FileOutputStream(file));
			logger.debug("call copy");

			long result = copyManager.copyOut(String.format("COPY %s TO STDOUT CSV HEADER FORCE QUOTE * ESCAPE '\\'",
					tableId), new FileOutputStream(file));
			logger.debug("Resource retrieved with successful");
			return result;	
		} finally {
			closeConn(conn);
		}
		
	}
	
}

==> statistical-manager-service-2.0.0-20160520.092413-25-sources.jar: org/gcube/data/analysis/statisticalmanager/dataspace/exporter/CSVExporter.java <==
package org.gcube.data.analysis.statisticalmanager.dataspace.exporter;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;

import org.gcube.data.analysis.statisticalmanager.exception.StatisticalManagerException;
import org.gcube.data.analysis.statisticalmanager.persistence.DataBaseManager;
import org.postgresql.copy.CopyManager;
import org.postgresql.core.BaseConnection;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class CSVExporter {

	private static Logger logger = LoggerFactory.getLogger(CSVExporter.class);
	private File file;
	private String tableId;
	
	public CSVExporter(String tableId, File file) {
		this.file = file;
		this.tableId = tableId;
	}
	
	public long exporterToFile() throws StatisticalManagerException, FileNotFoundException,
	SQLException, IOException,Exception {
		
		Connection conn = null;
		CopyManager copyManager = null;
		DataBaseManager db=null;
		try {
			db=DataBaseManager.get();
			conn = DriverManager.getConnection(db.getUrlDB(),
					db.getUsername(), db.getPassword());
			copyManager = new CopyManager((BaseConnection) conn);

			logger.debug("Try to retrieve resource");
			long result = copyManager.copyOut(String.format("COPY %s TO STDOUT CSV HEADER",
					tableId), new FileOutputStream(file));
			logger.debug("Resource retrieved with successful");
			return result;
			
		} catch (SQLException e) {		
			logger.error("Unexpected Error ",e);
			throw new StatisticalManagerException();
		}finally {
			if(db!=null)db.closeConn(conn);
		}
		
	}
	
}
